@@ -913,31 +913,19 @@ _g_path_remove_ending_separator (const char *path)
 }
 
 
-gchar *
+char *
 _g_path_remove_extension (const gchar *path)
 {
-	int         len;
-	int         p;
-	const char *ptr = path;
-	char       *new_path;
+	const char *ext;
 
-	if (! path)
-		return NULL;
-
-	len = strlen (path);
-	if (len == 1)
+	ext = _g_filename_get_extension (path);
+	if (ext == NULL)
 		return g_strdup (path);
-
-	p = len - 1;
-	while ((p > 0) && (ptr[p] != '.'))
-		p--;
-	if (p == 0)
-		p = len;
-	new_path = g_strndup (path, (guint) p);
-
-	return new_path;
+	else
+		return g_strndup (path, strlen (path) - strlen (ext));
 }
 
+
 /* Check whether the dirname is contained in filename */
 gboolean
 _g_path_is_parent_of (const char *dirname,
@@ -1233,6 +1221,33 @@ _g_file_append_path (GFile  *file,
 }
 
 
+/* GKeyFile */
+
+
+GList *
+_g_key_file_get_string_list (GKeyFile    *key_file,
+			     const char  *group_name,
+			     const char  *key,
+			     GError    **error)
+{
+	char  **strv;
+	GList  *list;
+	int     i;
+
+	strv = g_key_file_get_string_list (key_file, group_name, key, NULL, error);
+	if (strv == NULL)
+		return NULL;
+
+	list = NULL;
+	for (i = 0; strv[i] != NULL; i++)
+		list = g_list_prepend (list, strv[i]);
+
+	g_free (strv);
+
+	return g_list_reverse (list);
+}
+
+
 /* line parser */
 
 
